==> microprofile-metrics-api-tck-3.0-sources.jar: org/eclipse/microprofile/metrics/tck/tags/HistogramTagFieldBean.java <==
/*
 **********************************************************************
 * Copyright (c) 2019 Contributors to the Eclipse Foundation
 *
 * See the NOTICES file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 **********************************************************************/
package org.eclipse.microprofile.metrics.tck.tags;

import org.eclipse.microprofile.metrics.Histogram;
import org.eclipse.microprofile.metrics.annotation.Metric;

import javax.inject.Inject;

public class HistogramTagFieldBean {

    @Inject
    @Metric(name = "histogramName", tags= {"number=one"})
    private Histogram histogramOne;

    
    @Inject
    @Metric(name = "histogramName", tags= {"number=two"})
    private Histogram histogramTwo;
    
    public void updateOne(long n) {
        histogramOne.update(n);
    }
    
    public void updateTwo(long n) {
        histogramTwo.update(n);
    }
}

==> microprofile-metrics-api-tck-5.0.0-sources.jar: org/eclipse/microprofile/metrics/tck/tags/HistogramTagFieldBean.java <==
/*
 **********************************************************************
 * Copyright (c) 2019, 2022 Contributors to the Eclipse Foundation
 *
 * See the NOTICES file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 **********************************************************************/
package org.eclipse.microprofile.metrics.tck.tags;

import org.eclipse.microprofile.metrics.Histogram;
import org.eclipse.microprofile.metrics.annotation.Metric;

import jakarta.enterprise.context.Dependent;
import jakarta.inject.Inject;

@Dependent
public class HistogramTagFieldBean {

    @Inject
    @Metric(name = "histogramName", tags = {"number=one"})
    private Histogram histogramOne;

    @Inject
    @Metric(name = "histogramName", tags = {"number=two"})
    private Histogram histogramTwo;

    public void updateOne(long n) {
        histogramOne.update(n);
    }

    public void updateTwo(long n) {
        histogramTwo.update(n);
    }
}
